"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var read_events_exports = {};
__export(read_events_exports, {
  readEvents: () => readEvents
});
module.exports = __toCommonJS(read_events_exports);
var import_fs = __toESM(require("fs"));
var import_readline = __toESM(require("readline"));
var import_util = require("util");
var import_header = require("./header");
const log = require("@home-gallery/logger")("events.read");
const readEventsCb = (filename, cb) => {
  let isClosed = false;
  let header = false;
  const events = [];
  let reader;
  let lineNumber = 0;
  const readStream = import_fs.default.createReadStream(filename);
  readStream.on("error", (err) => {
    isClosed = true;
    cb(err);
    reader && reader.close();
  });
  const checkHeader = (data) => {
    if (!(0, import_header.isEventTypeCompatible)(data == null ? void 0 : data.type)) {
      const err = new Error(`Unknown events database header: '${JSON.stringify(data).substring(0, 45)}...'. Expect '{"type":"${import_header.HeaderType}",...}'`);
      log.error(err, err.message);
      return readStream.destroy(err);
    }
    header = data;
  };
  reader = import_readline.default.createInterface({
    input: readStream,
    terminal: false
  });
  reader.on("line", (line) => {
    try {
      const data = JSON.parse(line);
      if (lineNumber++ > 0) {
        events.push(data);
      } else {
        return checkHeader(data);
      }
    } catch (e) {
      log.error(e, `Could not parse line ${lineNumber}: ${line}`);
    }
  });
  reader.on("error", (err) => {
    if (isClosed) {
      return;
    }
    isClosed = true;
    cb(err);
    reader.close();
  });
  reader.on("close", () => {
    if (isClosed) {
      return;
    } else if (header) {
      header.data = events;
      cb(null, header);
    } else {
      cb(new Error(`No event header found`));
    }
  });
};
const readEvents = (0, import_util.promisify)(readEventsCb);
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  readEvents
});
//# sourceMappingURL=read-events.js.map
